"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWorkspace = void 0;
const tslib_1 = require("tslib");
const output_1 = require("./utils/output");
const nx_cloud_1 = require("./utils/nx/nx-cloud");
const create_sandbox_1 = require("./create-sandbox");
const create_empty_workspace_1 = require("./create-empty-workspace");
const create_preset_1 = require("./create-preset");
const show_nx_warning_1 = require("./utils/nx/show-nx-warning");
const setup_ci_1 = require("./utils/ci/setup-ci");
const ab_testing_1 = require("./utils/nx/ab-testing");
const git_1 = require("./utils/git/git");
const nx_version_1 = require("./utils/nx/nx-version");
const get_third_party_preset_1 = require("./utils/preset/get-third-party-preset");
const error_utils_1 = require("./utils/error-utils");
function createWorkspace(preset, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { packageManager, name, nxCloud, ci = '', skipGit = false, defaultBase = 'main', commit, } = options;
        output_1.output.log({
            title: `Nx is creating your v${nx_version_1.nxVersion} workspace.`,
            bodyLines: [
                'To make sure the command works reliably in all environments, and that the preset is applied correctly,',
                `Nx will run "${options.packageManager} install" several times. Please wait.`,
            ],
        });
        const tmpDir = yield (0, create_sandbox_1.createSandbox)(packageManager);
        const directory = yield (0, create_empty_workspace_1.createEmptyWorkspace)(tmpDir, name, packageManager, options);
        // If the preset is a third-party preset, we need to call createPreset to install it
        // For first-party presets, it will created by createEmptyWorkspace instead.
        // In createEmptyWorkspace, it will call `nx new` -> `@nrwl/workspace newGenerator` -> `@nrwl/workspace generatePreset`.
        const thirdPartyPreset = yield (0, get_third_party_preset_1.getThirdPartyPreset)(preset);
        if (thirdPartyPreset) {
            yield (0, create_preset_1.createPreset)(thirdPartyPreset, options, packageManager, directory);
        }
        let nxCloudInstallRes;
        if (nxCloud) {
            nxCloudInstallRes = yield (0, nx_cloud_1.setupNxCloud)(name, packageManager);
        }
        if (ci) {
            yield (0, setup_ci_1.setupCI)(name, ci, packageManager, nxCloud && (nxCloudInstallRes === null || nxCloudInstallRes === void 0 ? void 0 : nxCloudInstallRes.code) === 0);
        }
        if (!skipGit) {
            try {
                yield (0, git_1.initializeGitRepo)(directory, { defaultBase, commit });
            }
            catch (e) {
                if (e instanceof Error) {
                    output_1.output.error({
                        title: 'Could not initialize git repository',
                        bodyLines: (0, error_utils_1.mapErrorToBodyLines)(e),
                    });
                }
                else {
                    console.error(e);
                }
            }
        }
        (0, show_nx_warning_1.showNxWarning)(name);
        if (nxCloud && (nxCloudInstallRes === null || nxCloudInstallRes === void 0 ? void 0 : nxCloudInstallRes.code) === 0) {
            (0, nx_cloud_1.printNxCloudSuccessMessage)(nxCloudInstallRes.stdout);
        }
        yield (0, ab_testing_1.recordStat)({
            nxVersion: nx_version_1.nxVersion,
            command: 'create-nx-workspace',
            useCloud: nxCloud,
            meta: ab_testing_1.messages.codeOfSelectedPromptMessage('nxCloudCreation'),
        });
    });
}
exports.createWorkspace = createWorkspace;
//# sourceMappingURL=create-workspace.js.map